Put back 4096 for runall.sh batch size
authorMathieu Desnoyers <mathieu.desnoyers@polymtl.ca>
Thu, 18 Jun 2009 16:47:44 +0000 (12:47 -0400)
committerMathieu Desnoyers <mathieu.desnoyers@polymtl.ca>
Thu, 18 Jun 2009 16:47:44 +0000 (12:47 -0400)
Basically, when we get to 16384, it's the error due to non-handled removals that
makes this value "look" faster.

Signed-off-by: Mathieu Desnoyers <mathieu.desnoyers@polymtl.ca>
runall.sh

index 979a481cb0d240ffd9995bdd3f7bc06cc1df588f..3f38a050d9d2d5055c346cee362c52f6ec1d915a 100755 (executable)
--- a/runall.sh
+++ b/runall.sh
@@ -43,8 +43,8 @@ for BATCH_SIZE in ${BATCH_ARRAY}; do
        ./runtests-batch.sh ${NR_READERS} ${NR_WRITERS} ${DURATION} -d 0 -b ${BATCH_SIZE} ${EXTRA_OPTS} | tee -a batch-rcu.log
 done
 
-#setting gc each 16384. ** UPDATE FOR YOUR ARCHITECTURE BASED ON TEST ABOVE **
-EXTRA_OPTS+="-b 16384"
+#setting gc each 4096. ** UPDATE FOR YOUR ARCHITECTURE BASED ON TEST ABOVE **
+EXTRA_OPTS+="-b 4096"
 
 echo Executing update fraction test
 
This page took 0.025324 seconds and 4 git commands to generate.